#ifndef GRIDANALYSIS_H
#define GRIDANALYSIS_H
/******************************** Inclusions. *************/
SEXP gridanalysis (SEXP rpadding, SEXP rLL, SEXP rbbox) ;
#endif
